@@ -19,7 +19,6 @@ import logging
 from typing import Any, Callable, Dict, Optional
 
 from swh.core.db import BaseDb
-from swh.model.identifiers import ExtendedObjectType
 from swh.model.model import (
     BaseModel,
     Directory,
@@ -32,13 +31,14 @@ from swh.model.model import (
     SnapshotBranch,
     TargetType,
 )
+from swh.model.swhids import ExtendedObjectType
 from swh.storage.postgresql.converters import (
     db_to_extid,
     db_to_raw_extrinsic_metadata,
     db_to_release,
     db_to_revision,
 )
-from swh.storage.replay import object_converter_fn
+from swh.storage.replay import OBJECT_CONVERTERS
 from swh.storage.writer import JournalWriter
 
 logger = logging.getLogger(__name__)
@@ -79,7 +79,7 @@ COLUMNS = {
         "status",
         "reason",
     ],
-    "directory": ["id", "dir_entries", "file_entries", "rev_entries"],
+    "directory": ["id", "dir_entries", "file_entries", "rev_entries", "raw_manifest"],
     "extid": ["extid_type", "extid", "extid_version", "target_type", "target"],
     "metadata_authority": ["type", "url"],
     "metadata_fetcher": ["name", "version"],
@@ -117,9 +117,11 @@ COLUMNS = {
         "date",
         "date_offset",
         "date_neg_utc_offset",
+        "date_offset_bytes",
         "committer_date",
         "committer_date_offset",
         "committer_date_neg_utc_offset",
+        "committer_date_offset_bytes",
         "type",
         "directory",
         "message",
@@ -131,6 +133,7 @@ COLUMNS = {
             "where rh.id = revision.id order by rh.parent_rank asc)",
             "parents",
         ),
+        "raw_manifest",
         ("a.id", "author_id"),
         ("a.name", "author_name"),
         ("a.email", "author_email"),
@@ -145,6 +148,7 @@ COLUMNS = {
         "date",
         "date_offset",
         "date_neg_utc_offset",
+        "date_offset_bytes",
         "comment",
         ("release.name", "name"),
         "synthetic",
@@ -154,6 +158,7 @@ COLUMNS = {
         ("a.name", "author_name"),
         ("a.email", "author_email"),
         ("a.fullname", "author_fullname"),
+        "raw_manifest",
     ],
     "snapshot": ["id", "object_id"],
 }
@@ -541,7 +546,7 @@ def fetch(db, obj_type, start, end):
             if converter:
                 record = converter(db, record)
             else:
-                record = object_converter_fn[obj_type](record)
+                record = OBJECT_CONVERTERS[obj_type](record)
 
             logger.debug("record: %s", record)
             yield record
