@@ -28,8 +28,6 @@ import attr
 from swh.core.api.classes import stream_results
 from swh.core.api.serializers import msgpack_dumps, msgpack_loads
 from swh.model.hashutil import DEFAULT_ALGORITHMS, hash_to_hex
-from swh.model.identifiers import CoreSWHID, ExtendedObjectType, ExtendedSWHID
-from swh.model.identifiers import ObjectType as SwhidObjectType
 from swh.model.model import (
     Content,
     Directory,
@@ -50,6 +48,8 @@ from swh.model.model import (
     SnapshotBranch,
     TargetType,
 )
+from swh.model.swhids import CoreSWHID, ExtendedObjectType, ExtendedSWHID
+from swh.model.swhids import ObjectType as SwhidObjectType
 from swh.storage.interface import (
     VISIT_STATUSES,
     ListOrder,
@@ -504,7 +504,9 @@ class CassandraStorage:
             # Add the directory *after* adding all the entries, so someone
             # calling snapshot_get_branch in the meantime won't end up
             # with half the entries.
-            self._cql_runner.directory_add_one(DirectoryRow(id=directory.id))
+            self._cql_runner.directory_add_one(
+                DirectoryRow(id=directory.id, raw_manifest=directory.raw_manifest)
+            )
 
         return {"directory:add": len(directories)}
 
@@ -530,9 +532,11 @@ class CassandraStorage:
                 if dentry.target == content.sha1_git:
                     break
             else:
+                target = ret["target"]
+                assert target is not None
                 tokens = list(
                     self._cql_runner.skipped_content_get_tokens_from_single_hash(
-                        "sha1_git", ret["target"]
+                        "sha1_git", target
                     )
                 )
                 if tokens:
@@ -962,7 +966,7 @@ class CassandraStorage:
         queries: List[Tuple[str, Callable[[List[Sha1Git]], List[Sha1Git]]]] = [
             ("revision", self._cql_runner.revision_missing),
             ("release", self._cql_runner.release_missing),
-            ("content", self._cql_runner.content_missing_by_sha1_git),
+            ("content", self.content_missing_per_sha1_git),
             ("directory", self._cql_runner.directory_missing),
         ]
 
@@ -1090,6 +1094,10 @@ class CassandraStorage:
             "The Cassandra backend does not implement origin_count"
         )
 
+    @timed
+    def origin_snapshot_get_all(self, origin_url: str) -> List[Sha1Git]:
+        return list(self._cql_runner.origin_snapshot_get_all(origin_url))
+
     @timed
     @process_metrics
     def origin_add(self, origins: List[Origin]) -> Dict[str, int]:
