@@ -22,8 +22,8 @@ from typing import (
     Union,
 )
 
-from swh.model.identifiers import ExtendedSWHID
 from swh.model.model import Content, Sha1Git, SkippedContent
+from swh.model.swhids import ExtendedSWHID
 from swh.storage.cassandra import CassandraStorage
 from swh.storage.cassandra.model import (
     BaseRow,
@@ -583,6 +583,18 @@ class InMemoryCqlRunner:
         statuses.sort(key=lambda s: s.date, reverse=True)
         return iter(statuses)
 
+    def origin_snapshot_get_all(self, origin: str) -> Iterator[Sha1Git]:
+        """Return all snapshots for a given origin
+
+        """
+        return iter(
+            {
+                s.snapshot
+                for s in self._origin_visit_statuses.get_from_partition_key((origin,))
+                if s.snapshot is not None
+            }
+        )
+
     ##########################
     # 'metadata_authority' table
     ##########################
