@@ -39,13 +39,6 @@ import psycopg2
 
 from swh.core.db import BaseDb
 from swh.model.hashutil import hash_to_hex
-from swh.model.identifiers import (
-    CoreSWHID,
-    ExtendedObjectType,
-    ExtendedSWHID,
-    ObjectType,
-    QualifiedSWHID,
-)
 from swh.model.model import (
     MetadataAuthority,
     MetadataAuthorityType,
@@ -53,6 +46,13 @@ from swh.model.model import (
     RawExtrinsicMetadata,
     Sha1Git,
 )
+from swh.model.swhids import (
+    CoreSWHID,
+    ExtendedObjectType,
+    ExtendedSWHID,
+    ObjectType,
+    QualifiedSWHID,
+)
 from swh.storage import get_storage
 from swh.storage.algos.origin import iter_origin_visit_statuses, iter_origin_visits
 from swh.storage.algos.snapshot import snapshot_get_all_branches
