@@ -14,8 +14,8 @@ from swh.core.db.db_utils import execute_values_generator
 from swh.core.db.db_utils import jsonize as _jsonize
 from swh.core.db.db_utils import stored_procedure
 from swh.model.hashutil import DEFAULT_ALGORITHMS
-from swh.model.identifiers import ObjectType
 from swh.model.model import SHA1_SIZE, OriginVisit, OriginVisitStatus, Sha1Git
+from swh.model.swhids import ObjectType
 from swh.storage.interface import ListOrder
 
 logger = logging.getLogger(__name__)
@@ -30,7 +30,7 @@ class Db(BaseDb):
 
     """
 
-    current_version = 178
+    current_version = 180
 
     def mktemp_dir_entry(self, entry_type, cur=None):
         self._cursor(cur).execute(
@@ -437,9 +437,11 @@ class Db(BaseDb):
         "date",
         "date_offset",
         "date_neg_utc_offset",
+        "date_offset_bytes",
         "committer_date",
         "committer_date_offset",
         "committer_date_neg_utc_offset",
+        "committer_date_offset_bytes",
         "type",
         "directory",
         "message",
@@ -452,6 +454,7 @@ class Db(BaseDb):
         "metadata",
         "synthetic",
         "extra_headers",
+        "raw_manifest",
     ]
 
     revision_get_cols = revision_add_cols + ["parents"]
@@ -1200,15 +1203,27 @@ class Db(BaseDb):
         "date",
         "date_offset",
         "date_neg_utc_offset",
+        "date_offset_bytes",
         "name",
         "comment",
         "synthetic",
+        "raw_manifest",
         "author_fullname",
         "author_name",
         "author_email",
     ]
     release_get_cols = release_add_cols
 
+    def origin_snapshot_get_all(self, origin_url: str, cur=None) -> Iterable[Sha1Git]:
+        cur = self._cursor(cur)
+        query = f"""\
+        SELECT DISTINCT snapshot FROM origin_visit_status ovs
+        INNER JOIN origin o ON o.id = ovs.origin
+        WHERE o.url = '{origin_url}' and snapshot IS NOT NULL;
+        """
+        cur.execute(query)
+        yield from map(lambda row: row[0], cur)
+
     def release_get_from_list(self, releases, cur=None):
         cur = self._cursor(cur)
         query_keys = ", ".join(
