@@ -20,7 +20,6 @@ import psycopg2.pool
 from swh.core.api.serializers import msgpack_dumps, msgpack_loads
 from swh.core.db.common import db_transaction, db_transaction_generator
 from swh.model.hashutil import DEFAULT_ALGORITHMS, hash_to_bytes, hash_to_hex
-from swh.model.identifiers import ExtendedObjectType, ExtendedSWHID, ObjectType
 from swh.model.model import (
     SHA1_SIZE,
     Content,
@@ -43,6 +42,7 @@ from swh.model.model import (
     SnapshotBranch,
     TargetType,
 )
+from swh.model.swhids import ExtendedObjectType, ExtendedSWHID, ObjectType
 from swh.storage.exc import HashCollision, StorageArgumentException, StorageDBError
 from swh.storage.interface import (
     VISIT_STATUSES,
@@ -118,6 +118,9 @@ class Storage:
             if isinstance(db, psycopg2.extensions.connection):
                 self._pool = None
                 self._db = Db(db)
+
+                # See comment below
+                self._db.cursor().execute("SET TIME ZONE 'UTC'")
             else:
                 self._pool = psycopg2.pool.ThreadedConnectionPool(
                     min_pool_conns, max_pool_conns, db
@@ -133,7 +136,15 @@ class Storage:
         if self._db:
             return self._db
         else:
-            return Db.from_pool(self._pool)
+            db = Db.from_pool(self._pool)
+
+            # Workaround for psycopg2 < 2.9.0 not handling fractional timezones,
+            # which may happen on old revision/release dates on systems configured
+            # with non-UTC timezones.
+            # https://www.psycopg.org/docs/usage.html#time-zones-handling
+            db.cursor().execute("SET TIME ZONE 'UTC'")
+
+            return db
 
     def put_db(self, db):
         if db is not self._db:
@@ -513,7 +524,7 @@ class Storage:
         # Copy directory ids
         dirs_missing_dict = ({"id": dir} for dir in dirs_missing)
         db.mktemp("directory", cur)
-        db.copy_to(dirs_missing_dict, "tmp_directory", ["id"], cur)
+        db.copy_to(dirs_missing_dict, "tmp_directory", ["id", "raw_manifest"], cur)
 
         # Copy entries
         for entry_type, entry_list in dir_entries.items():
@@ -1350,6 +1361,13 @@ class Storage:
     ) -> int:
         return db.origin_count(url_pattern, regexp, with_visit, cur)
 
+    @timed
+    @db_transaction()
+    def origin_snapshot_get_all(
+        self, origin_url: str, *, db: Db, cur=None
+    ) -> List[Sha1Git]:
+        return list(db.origin_snapshot_get_all(origin_url, cur))
+
     @timed
     @process_metrics
     @db_transaction()
