@@ -3,6 +3,8 @@
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
+from unittest.mock import Mock
+
 import attr
 import pytest
 
@@ -110,6 +112,26 @@ def test_filtering_proxy_storage_revision(swh_storage, sample_data):
     }
 
 
+def test_filtering_proxy_storage_release(swh_storage, sample_data):
+    sample_release = sample_data.release
+
+    release = swh_storage.release_get([sample_release.id])[0]
+    assert release is None
+
+    s = swh_storage.release_add([sample_release])
+    assert s == {
+        "release:add": 1,
+    }
+
+    release = swh_storage.release_get([sample_release.id])[0]
+    assert release is not None
+
+    s = swh_storage.release_add([sample_release])
+    assert s == {
+        "release:add": 0,
+    }
+
+
 def test_filtering_proxy_storage_directory(swh_storage, sample_data):
     sample_directory = sample_data.directory
 
@@ -128,3 +150,32 @@ def test_filtering_proxy_storage_directory(swh_storage, sample_data):
     assert s == {
         "directory:add": 0,
     }
+
+
+def test_filtering_proxy_storage_empty_list(swh_storage, sample_data):
+    swh_storage.storage = mock_storage = Mock(wraps=swh_storage.storage)
+
+    calls = 0
+    for object_type in swh_storage.object_types:
+        calls += 1
+
+        method_name = f"{object_type}_add"
+        method = getattr(swh_storage, method_name)
+        one_object = getattr(sample_data, object_type)
+
+        # Call with empty list: ensure underlying storage not called
+        method([])
+        assert method_name not in {c[0] for c in mock_storage.method_calls}
+        mock_storage.reset_mock()
+
+        # Call with an object: ensure underlying storage is called
+        method([one_object])
+        assert method_name in {c[0] for c in mock_storage.method_calls}
+        mock_storage.reset_mock()
+
+        # Call with the same object: ensure underlying storage is not called again
+        method([one_object])
+        assert method_name not in {c[0] for c in mock_storage.method_calls}
+        mock_storage.reset_mock()
+
+    assert calls > 0, "Empty list never tested"
